@@ -2,8 +2,8 @@ import inspect
 import logging
 import threading
 
-from ...exceptions import ResourceLocked, ResourceNotLocked
 from ..decorators import wraps
+from ...exceptions import ResourceLocked, ResourceNotLocked
 
 logger = logging.getLogger(__name__)
 
@@ -35,13 +35,15 @@ class LockedDataset:
     """
 
     class InternalDataset(object):
+        __slots__ = ('lock', 'locked', 'args')
+
         def __init__(self):
             self.lock = threading.Lock()
             self.locked = False
             self.args = ()
 
     def __init__(self):
-        self.__internal = LockedDataset.InternalDataset()
+        self.__internal = LockedDataset.InternalDataset()  # type: LockedDataset.InternalDataset
 
     @staticmethod
     def locked(blocking=True, timeout=-1):
