@@ -1,8 +1,8 @@
-import typing as tp
 import collections
 import copy
 import logging
 import threading
+import typing as tp
 
 from ..decorators import wraps
 
@@ -39,6 +39,8 @@ class Monitor:
     >>>         with self:
     >>>             .. do your threadsafe jobs ..
     """
+    __slots__ = ('_monitor_lock',)
+
     def __enter__(self):
         self._monitor_lock.acquire()
         return self
@@ -50,7 +52,7 @@ class Monitor:
     def __init__(self):
         """You need to invoke this at your constructor
         You can also use it to release locks of other objects."""
-        self._monitor_lock = threading.Lock()
+        self._monitor_lock = threading.Lock()  # type: threading.Lock
 
     @staticmethod
     def synchronized(fun):
@@ -137,12 +139,15 @@ class Monitor:
         >>>                 ...
         >>>         return SlaveClass
         """
+
         def outer(fun):
             @wraps(fun)
             def inner(*args, **kwargs):
                 with cls.acquire(monitor):
                     return fun(*args, **kwargs)
+
             return inner
+
         return outer
 
 
@@ -152,11 +157,12 @@ class RMonitor(Monitor):
     """
 
     def __init__(self):
-        self._monitor_lock = threading.RLock()
+        self._monitor_lock = threading.RLock()  # type: threading.RLock
 
 
 class MonitorList(tp.Generic[T], collections.UserList, Monitor):
     """A list that is also a monitor"""
+
     def __init__(self, *args):
         collections.UserList.__init__(self, *args)
         Monitor.__init__(self)
@@ -179,6 +185,7 @@ class MonitorList(tp.Generic[T], collections.UserList, Monitor):
 
 class MonitorDict(tp.Generic[K, V], collections.UserDict, Monitor):
     """A dict that is also a monitor"""
+
     def __init__(self, *args, **kwargs):
         collections.UserDict.__init__(self, *args, **kwargs)
         Monitor.__init__(self)
