@@ -1,14 +1,17 @@
-from .dict_object import *
+from .dictionaries import DictObject, apply_dict_object, DictionaryView
+from .hashable_objects import HashableWrapper
 from .immutable import Immutable, frozendict
 from .singleton import Singleton, SingletonWithRegardsTo
-from .structures import *
-from .typednamedtuple import *
+from .structures import SetHeap, OmniHashableMixin, TimeBasedHeap, Heap
+from .typednamedtuple import typednamedtuple
 
 __all__ = [
     'typednamedtuple',
+    'HashableWrapper',
     'Heap',
     'SetHeap',
-    'frozendict'
+    'DictionaryView',
+    'frozendict',
     'TimeBasedHeap',
     'OmniHashableMixin',
     'Singleton',
