@@ -14,16 +14,16 @@ def join_metric_data_name(prefix: str, name: str):
 
 
 class MetricData(JSONAble):
-    __slots__ = ['name', 'value', 'labels', 'timestamp', 'internal']
+    __slots__ = ('name', 'value', 'labels', 'timestamp', 'internal')
 
     def __init__(self, name: str, value: float, labels: dict = None,
                  timestamp: tp.Optional[float] = None,
                  internal: bool = False):
-        self.name = name
-        self.internal = internal
-        self.value = value
+        self.name = name                    # type: str
+        self.internal = internal            # type: bool
+        self.value = value                  # type: tp.Any
         self.labels = frozendict(labels) if labels is not None else frozendict()
-        self.timestamp = timestamp
+        self.timestamp = timestamp          # type: tp.Optional[float]
 
     def add_labels(self, labels: dict) -> None:
         labels_current = dict(self.labels)
@@ -71,6 +71,8 @@ class MetricData(JSONAble):
 
 
 class MetricDataCollection(JSONAble):
+    __slots__ = ('values', )
+
     def add_labels(self, labels: dict) -> None:
         output = set()
         for child in self.values:
