@@ -1,4 +1,3 @@
-import time
 import logging
 import typing as tp
 
@@ -12,12 +11,14 @@ logger = logging.getLogger(__name__)
 
 
 class SimpleMetric(EmbeddedSubmetrics):
+    __slots__ = ('data', )
+
     CLASS_NAME = 'string'
     CONSTRUCTOR = str
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.data = None
+        self.data = None                # type: tp.Any
 
     def _handle(self, value, **labels) -> None:
         if self.embedded_submetrics_enabled or labels:
